You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@unomi.apache.org by dg...@apache.org on 2017/10/06 13:33:31 UTC

[07/15] incubator-unomi git commit: UNOMI-117 move tags from the root of property type to their metadata to reflect others object structure

UNOMI-117 move tags from the root of property type to their metadata to reflect others object structure


Project: http://git-wip-us.apache.org/repos/asf/incubator-unomi/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-unomi/commit/a5beefc4
Tree: http://git-wip-us.apache.org/repos/asf/incubator-unomi/tree/a5beefc4
Diff: http://git-wip-us.apache.org/repos/asf/incubator-unomi/diff/a5beefc4

Branch: refs/heads/master
Commit: a5beefc459bed4205425832b0e8e8534e84e7ab9
Parents: eb8f07b
Author: dgaillard <dg...@jahia.com>
Authored: Fri Sep 15 17:57:09 2017 +0200
Committer: dgaillard <dg...@jahia.com>
Committed: Thu Sep 28 10:50:13 2017 +0200

----------------------------------------------------------------------
 .../java/org/apache/unomi/api/PropertyType.java | 19 ----------------
 .../sessions/weather/weatherLike.json           |  9 ++++----
 .../sessions/weather/weatherTemp.json           |  9 ++++----
 .../sessions/weather/weatherWindDirection.json  |  9 ++++----
 .../sessions/weather/weatherWindSpeed.json      |  9 ++++----
 .../unomi/rest/ProfileServiceEndPoint.java      | 12 +++++-----
 .../actions/IncrementTweetNumberAction.java     |  4 ++--
 .../services/services/ProfileServiceImpl.java   |  2 +-
 .../properties/profiles/basic/firstName.json    | 15 ++++++++-----
 .../cxs/properties/profiles/basic/gender.json   | 15 ++++++++-----
 .../cxs/properties/profiles/basic/lastName.json | 15 ++++++++-----
 .../properties/profiles/basic/nationality.json  | 15 ++++++++-----
 .../properties/profiles/contact/address.json    | 23 +++++++++++---------
 .../cxs/properties/profiles/contact/city.json   | 15 ++++++++-----
 .../profiles/contact/countryName.json           | 15 ++++++++-----
 .../cxs/properties/profiles/contact/email.json  | 15 ++++++++-----
 .../profiles/contact/phoneNumber.json           | 15 ++++++++-----
 .../properties/profiles/contact/zipCode.json    | 15 ++++++++-----
 .../profiles/lead/leadAssignedTo.json           | 15 ++++++++-----
 .../cxs/properties/profiles/personal/age.json   | 12 +++++-----
 .../properties/profiles/personal/birthDate.json | 12 +++++-----
 .../cxs/properties/profiles/personal/kids.json  | 15 ++++++++-----
 .../profiles/personal/maritalStatus.json        | 15 ++++++++-----
 .../properties/profiles/social/facebookId.json  | 15 ++++++++-----
 .../properties/profiles/social/googleid.json    | 15 ++++++++-----
 .../properties/profiles/social/linkedInId.json  | 15 ++++++++-----
 .../properties/profiles/social/twitterId.json   | 15 ++++++++-----
 .../properties/profiles/system/firstVisit.json  | 15 ++++++++-----
 .../properties/profiles/system/lastVisit.json   | 15 ++++++++-----
 .../properties/profiles/system/nbOfVisits.json  | 15 ++++++++-----
 .../profiles/system/previousVisit.json          | 15 ++++++++-----
 .../cxs/properties/profiles/work/company.json   | 15 ++++++++-----
 .../cxs/properties/profiles/work/income.json    | 15 ++++++++-----
 .../cxs/properties/profiles/work/jobTitle.json  | 15 ++++++++-----
 .../sessions/geographic/latitude.json           | 15 ++++++++-----
 .../sessions/geographic/longitude.json          | 15 ++++++++-----
 .../geographic/sessionAdminSubDiv1.json         | 15 ++++++++-----
 .../geographic/sessionAdminSubDiv2.json         | 15 ++++++++-----
 .../sessions/geographic/sessionCity.json        | 15 ++++++++-----
 .../sessions/geographic/sessionCountryCode.json | 15 ++++++++-----
 .../sessions/geographic/sessionCountryName.json | 15 ++++++++-----
 .../sessions/technical/deviceCategory.json      | 15 ++++++++-----
 .../technical/operatingSystemFamily.json        | 15 ++++++++-----
 .../sessions/technical/operatingSystemName.json | 15 ++++++++-----
 .../sessions/technical/pageReferringURL.json    | 15 ++++++++-----
 .../sessions/technical/remoteAddr.json          | 15 ++++++++-----
 .../sessions/technical/remoteHost.json          | 15 ++++++++-----
 .../sessions/technical/userAgentName.json       | 15 ++++++++-----
 .../sessions/technical/userAgentVersion.json    | 15 ++++++++-----
 src/site/markdown/versions/1.1/concepts.md      |  4 ++--
 src/site/markdown/versions/master/concepts.md   |  4 ++--
 .../versions/master/custom-extensions.md        |  7 ++++--
 52 files changed, 404 insertions(+), 301 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/api/src/main/java/org/apache/unomi/api/PropertyType.java
----------------------------------------------------------------------
diff --git a/api/src/main/java/org/apache/unomi/api/PropertyType.java b/api/src/main/java/org/apache/unomi/api/PropertyType.java
index 01bc934..45a81cb 100644
--- a/api/src/main/java/org/apache/unomi/api/PropertyType.java
+++ b/api/src/main/java/org/apache/unomi/api/PropertyType.java
@@ -46,7 +46,6 @@ public class PropertyType extends MetadataItem {
     private Set<String> automaticMappingsFrom = new HashSet<>();
     private Double rank;
     private String mergeStrategy;
-    private Set<String> tags = new LinkedHashSet<>();
     private Boolean multivalued;
     private Boolean protekted;
 
@@ -128,24 +127,6 @@ public class PropertyType extends MetadataItem {
     }
 
     /**
-     * Retrieves the tags used by this PropertyType.
-     *
-     * @return the tags used by this PropertyType
-     */
-    public Set<String> getTags() {
-        return tags;
-    }
-
-    /**
-     * Sets the tags used by this PropertyType.
-     *
-     * @param tags the tags used by this PropertyType
-     */
-    public void setTags(Set<String> tags) {
-        this.tags = tags;
-    }
-
-    /**
      * Retrieves the default value defined for property using this PropertyType.
      *
      * @return the default value defined for property using this PropertyType

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherLike.json
----------------------------------------------------------------------
diff --git a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherLike.json b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherLike.json
index ade7495..5f9a5bf 100755
--- a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherLike.json
+++ b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherLike.json
@@ -1,12 +1,13 @@
 {
   "metadata": {
     "id": "weatherLike",
-    "name": "Weather Description"
+    "name": "Weather Description",
+    "tags": [
+      "properties",
+      "sessionProperties"
+    ]
   },
   "type": "string",
-  "tags": [
-    "sessionProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [],
   "rank": "302.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherTemp.json
----------------------------------------------------------------------
diff --git a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherTemp.json b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherTemp.json
index d3aebe5..11865d8 100755
--- a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherTemp.json
+++ b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherTemp.json
@@ -1,12 +1,13 @@
 {
   "metadata": {
     "id": "weatherTemperature",
-    "name": "Weather Temperature"
+    "name": "Weather Temperature",
+    "tags": [
+      "properties",
+      "sessionProperties"
+    ]
   },
   "type": "integer",
-  "tags": [
-    "sessionProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [],
   "rank": "302.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindDirection.json
----------------------------------------------------------------------
diff --git a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindDirection.json b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindDirection.json
index c9fc3e6..8e99d87 100755
--- a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindDirection.json
+++ b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindDirection.json
@@ -1,12 +1,13 @@
 {
   "metadata": {
     "id": "weatherWindDirection",
-    "name": "Weather Wind Direction"
+    "name": "Weather Wind Direction",
+    "tags": [
+      "properties",
+      "sessionProperties"
+    ]
   },
   "type": "string",
-  "tags": [
-    "sessionProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [],
   "rank": "302.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindSpeed.json
----------------------------------------------------------------------
diff --git a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindSpeed.json b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindSpeed.json
index 5077f1e..422090d 100755
--- a/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindSpeed.json
+++ b/extensions/weather-update/core/src/main/resources/META-INF/cxs/properties/sessions/weather/weatherWindSpeed.json
@@ -1,12 +1,13 @@
 {
   "metadata": {
     "id": "weatherWindSpeed",
-    "name": "Weather Wind Speed"
+    "name": "Weather Wind Speed",
+    "tags": [
+      "properties",
+      "sessionProperties"
+    ]
   },
   "type": "integer",
-  "tags": [
-    "sessionProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [],
   "rank": "302.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/rest/src/main/java/org/apache/unomi/rest/ProfileServiceEndPoint.java
----------------------------------------------------------------------
diff --git a/samples/tweet-button-plugin/src/main/java/org/apache/unomi/samples/tweet_button_plugin/actions/IncrementTweetNumberAction.java b/samples/tweet-button-plugin/src/main/java/org/apache/unomi/samples/tweet_button_plugin/actions/IncrementTweetNumberAction.java
index d291f09..c6fa4e5 100644
--- a/samples/tweet-button-plugin/src/main/java/org/apache/unomi/samples/tweet_button_plugin/actions/IncrementTweetNumberAction.java
+++ b/samples/tweet-button-plugin/src/main/java/org/apache/unomi/samples/tweet_button_plugin/actions/IncrementTweetNumberAction.java
@@ -45,14 +45,14 @@ public class IncrementTweetNumberAction implements ActionExecutor {
             // create tweet number property type
             PropertyType propertyType = new PropertyType(new Metadata(event.getScope(), TWEET_NB_PROPERTY, TWEET_NB_PROPERTY, "Number of times a user tweeted"));
             propertyType.setValueTypeId("integer");
-            propertyType.setTags(Collections.singleton("social"));
+            propertyType.getMetadata().setTags(Collections.singleton("social"));
             propertyType.setTarget(TARGET);
             service.setPropertyType(propertyType);
 
             // create tweeted from property type
             propertyType = new PropertyType(new Metadata(event.getScope(), TWEETED_FROM_PROPERTY, TWEETED_FROM_PROPERTY, "The list of pages a user tweeted from"));
             propertyType.setValueTypeId("string");
-            propertyType.setTags(Collections.singleton("social"));
+            propertyType.getMetadata().setTags(Collections.singleton("social"));
             propertyType.setTarget(TARGET);
             propertyType.setMultivalued(true);
             service.setPropertyType(propertyType);

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/java/org/apache/unomi/services/services/ProfileServiceImpl.java
----------------------------------------------------------------------
diff --git a/services/src/main/java/org/apache/unomi/services/services/ProfileServiceImpl.java b/services/src/main/java/org/apache/unomi/services/services/ProfileServiceImpl.java
index 273b64c..b95363c 100644
--- a/services/src/main/java/org/apache/unomi/services/services/ProfileServiceImpl.java
+++ b/services/src/main/java/org/apache/unomi/services/services/ProfileServiceImpl.java
@@ -641,7 +641,7 @@ public class ProfileServiceImpl implements ProfileService, SynchronousBundleList
 
     public Set<PropertyType> getPropertyTypeByTag(String tag) {
         Set<PropertyType> propertyTypes = new LinkedHashSet<PropertyType>();
-        Collection<PropertyType> directPropertyTypes = persistenceService.query("tags", tag, "rank", PropertyType.class);
+        Collection<PropertyType> directPropertyTypes = persistenceService.query("metadata.tags", tag, "rank", PropertyType.class);
 
         if (directPropertyTypes != null) {
             propertyTypes.addAll(directPropertyTypes);

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/basic/firstName.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/firstName.json b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/firstName.json
index a538e3e..1104066 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/firstName.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/firstName.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "firstName", "name": "First name"   },
+    "metadata": {
+        "id": "firstName",
+        "name": "First name",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "basicProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "basicProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "101.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/basic/gender.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/gender.json b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/gender.json
index 425b6bd..5a39b39 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/gender.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/gender.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "gender", "name": "Gender"   },
+    "metadata": {
+        "id": "gender",
+        "name": "Gender",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "basicProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "basicProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "104.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/basic/lastName.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/lastName.json b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/lastName.json
index ae43fc4..b7aaa1c 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/lastName.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/lastName.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "lastName", "name": "Last name"   },
+    "metadata": {
+        "id": "lastName",
+        "name": "Last name",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "basicProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "basicProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "102.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/basic/nationality.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/nationality.json b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/nationality.json
index 72f3dee..06fa815 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/basic/nationality.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/basic/nationality.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "nationality", "name": "Nationality"   },
+    "metadata": {
+        "id": "nationality",
+        "name": "Nationality",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "basicProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "basicProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "103.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/contact/address.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/address.json b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/address.json
index ad1cac4..4bab6c8 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/address.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/address.json
@@ -1,12 +1,15 @@
 {
-  "metadata": {"id": "address", "name": "Address"},
-  "type": "string",
-  "tags": [
-    "properties",
-    "profileProperties",
-    "contactProfileProperties"
-  ],
-  "defaultValue": "",
-  "automaticMappingsFrom": [],
-  "rank": "303.0"
+    "metadata": {
+        "id": "address",
+        "name": "Address",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "contactProfileProperties"
+        ]
+    },
+    "type": "string",
+    "defaultValue": "",
+    "automaticMappingsFrom": [],
+    "rank": "303.0"
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/contact/city.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/city.json b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/city.json
index e8bfe3a..166baba 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/city.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/city.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "city", "name": "City"   },
+    "metadata": {
+        "id": "city",
+        "name": "City",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "contactProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "contactProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "304.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/contact/countryName.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/countryName.json b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/countryName.json
index 5c5b1ae..1e34b94 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/countryName.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/countryName.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "countryName", "name": "Country"   },
+    "metadata": {
+        "id": "countryName",
+        "name": "Country",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "contactProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "contactProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "305.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/contact/email.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/email.json b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/email.json
index 3cd1d15..028eee3 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/email.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/email.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "email", "name": "Email"   },
+    "metadata": {
+        "id": "email",
+        "name": "Email",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "contactProfileProperties"
+        ]
+    },
     "type": "email",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "contactProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "301.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/contact/phoneNumber.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/phoneNumber.json b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/phoneNumber.json
index bd4319f..3c40ff1 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/phoneNumber.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/phoneNumber.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "phoneNumber", "name": "Phone number"   },
+    "metadata": {
+        "id": "phoneNumber",
+        "name": "Phone number",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "contactProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "contactProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "302.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/contact/zipCode.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/zipCode.json b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/zipCode.json
index 081313a..ff1f676 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/contact/zipCode.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/contact/zipCode.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "zipCode", "name": "ZIP Code"   },
+    "metadata": {
+        "id": "zipCode",
+        "name": "ZIP Code",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "contactProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "contactProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "306.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/lead/leadAssignedTo.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/lead/leadAssignedTo.json b/services/src/main/resources/META-INF/cxs/properties/profiles/lead/leadAssignedTo.json
index 4e445bd..7d1f66d 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/lead/leadAssignedTo.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/lead/leadAssignedTo.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "leadAssignedTo", "name": "Assigned to"   },
+    "metadata": {
+        "id": "leadAssignedTo",
+        "name": "Assigned to",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "leadProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "leadProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "201.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/personal/age.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/age.json b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/age.json
index 2f155f2..cd0f03d 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/age.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/age.json
@@ -1,14 +1,14 @@
 {
   "metadata": {
     "id": "age",
-    "name": "Age"
+    "name": "Age",
+    "tags": [
+      "properties",
+      "profileProperties",
+      "personalProfileProperties"
+    ]
   },
   "type": "integer",
-  "tags": [
-    "properties",
-    "profileProperties",
-    "personalProfileProperties"
-  ],
   "defaultValue": "",
   "numericRanges": [
     {"key":"*_10", "to" : 10 },

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/personal/birthDate.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/birthDate.json b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/birthDate.json
index 2d1101d..ef6dee5 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/birthDate.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/birthDate.json
@@ -1,14 +1,14 @@
 {
   "metadata": {
     "id": "birthDate",
-    "name": "Birth Date"
+    "name": "Birth Date",
+    "tags": [
+      "properties",
+      "profileProperties",
+      "personalProfileProperties"
+    ]
   },
   "type": "date",
-  "tags": [
-    "properties",
-    "profileProperties",
-    "personalProfileProperties"
-  ],
   "defaultValue": "",
   "dateRanges": [
     {"key":"*_10", "from": "now-10y/y" },

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/personal/kids.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/kids.json b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/kids.json
index 0a58820..f422883 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/kids.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/kids.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "kids", "name": "Kids"   },
+    "metadata": {
+        "id": "kids",
+        "name": "Kids",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "personalProfileProperties"
+        ]
+    },
     "type": "integer",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "personalProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "504.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/personal/maritalStatus.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/maritalStatus.json b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/maritalStatus.json
index 5bcd149..774f8f5 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/personal/maritalStatus.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/personal/maritalStatus.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "maritalStatus", "name": "Marital status"   },
+    "metadata": {
+        "id": "maritalStatus",
+        "name": "Marital status",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "personalProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "personalProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "503.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/social/facebookId.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/social/facebookId.json b/services/src/main/resources/META-INF/cxs/properties/profiles/social/facebookId.json
index b325f19..5f912ee 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/social/facebookId.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/social/facebookId.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "facebookId", "name": "Facebook ID"   },
+    "metadata": {
+        "id": "facebookId",
+        "name": "Facebook ID",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "socialProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "socialProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "401.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/social/googleid.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/social/googleid.json b/services/src/main/resources/META-INF/cxs/properties/profiles/social/googleid.json
index 48d54b8..6b1806a 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/social/googleid.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/social/googleid.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "googleId", "name": "Google ID"   },
+    "metadata": {
+        "id": "googleId",
+        "name": "Google ID",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "socialProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "socialProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "403.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/social/linkedInId.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/social/linkedInId.json b/services/src/main/resources/META-INF/cxs/properties/profiles/social/linkedInId.json
index a6947e1..d6b6ad6 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/social/linkedInId.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/social/linkedInId.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "linkedInId", "name": "LinkedIn ID"   },
+    "metadata": {
+        "id": "linkedInId",
+        "name": "LinkedIn ID",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "socialProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "socialProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "402.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/social/twitterId.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/social/twitterId.json b/services/src/main/resources/META-INF/cxs/properties/profiles/social/twitterId.json
index 40fad1d..a3789c6 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/social/twitterId.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/social/twitterId.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "twitterId", "name": "Twitter ID"   },
+    "metadata": {
+        "id": "twitterId",
+        "name": "Twitter ID",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "socialProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "socialProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "404.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/system/firstVisit.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/system/firstVisit.json b/services/src/main/resources/META-INF/cxs/properties/profiles/system/firstVisit.json
index e1f4f32..058bcbe 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/system/firstVisit.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/system/firstVisit.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "firstVisit", "name": "First visit"   },
+    "metadata": {
+        "id": "firstVisit",
+        "name": "First visit",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "systemProfileProperties"
+        ]
+    },
     "type": "date",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "systemProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "mergeStrategy": "oldestMergeStrategy",

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/system/lastVisit.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/system/lastVisit.json b/services/src/main/resources/META-INF/cxs/properties/profiles/system/lastVisit.json
index db2ffb9..d784f5c 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/system/lastVisit.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/system/lastVisit.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "lastVisit", "name": "Last visit"   },
+    "metadata": {
+        "id": "lastVisit",
+        "name": "Last visit",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "systemProfileProperties"
+        ]
+    },
     "type": "date",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "systemProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "mergeStrategy": "mostRecentMergeStrategy",

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/system/nbOfVisits.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/system/nbOfVisits.json b/services/src/main/resources/META-INF/cxs/properties/profiles/system/nbOfVisits.json
index 94a9123..5759e36 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/system/nbOfVisits.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/system/nbOfVisits.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "nbOfVisits", "name": "Number of visits"   },
+    "metadata": {
+      "id": "nbOfVisits",
+      "name": "Number of visits",
+      "tags": [
+        "properties",
+        "profileProperties",
+        "systemProfileProperties"
+      ]
+    },
     "type": "integer",
-    "tags": [
-      "properties",
-      "profileProperties",
-      "systemProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "numericRanges": [

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/system/previousVisit.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/system/previousVisit.json b/services/src/main/resources/META-INF/cxs/properties/profiles/system/previousVisit.json
index a06f26f..4aa04a1 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/system/previousVisit.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/system/previousVisit.json
@@ -1,11 +1,14 @@
 {
-  "metadata": {     "id": "previousVisit", "name": "Previous visit"   },
+  "metadata": {
+    "id": "previousVisit",
+    "name": "Previous visit",
+    "tags": [
+      "properties",
+      "profileProperties",
+      "systemProfileProperties"
+    ]
+  },
   "type": "date",
-  "tags": [
-    "properties",
-    "profileProperties",
-    "systemProfileProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [ ],
   "mergeStrategy": "mostRecentMergeStrategy",

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/work/company.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/work/company.json b/services/src/main/resources/META-INF/cxs/properties/profiles/work/company.json
index 940792b..18a4ee2 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/work/company.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/work/company.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "company", "name": "Company"   },
+    "metadata": {
+        "id": "company",
+        "name": "Company",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "workProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "workProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "601.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/work/income.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/work/income.json b/services/src/main/resources/META-INF/cxs/properties/profiles/work/income.json
index 47df006..d9a88a0 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/work/income.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/work/income.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "income", "name": "Income"   },
+    "metadata": {
+        "id": "income",
+        "name": "Income",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "workProfileProperties"
+        ]
+    },
     "type": "integer",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "workProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "603.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/profiles/work/jobTitle.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/profiles/work/jobTitle.json b/services/src/main/resources/META-INF/cxs/properties/profiles/work/jobTitle.json
index 22cc39f..fc0ca15 100644
--- a/services/src/main/resources/META-INF/cxs/properties/profiles/work/jobTitle.json
+++ b/services/src/main/resources/META-INF/cxs/properties/profiles/work/jobTitle.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "jobTitle", "name": "Job Title"   },
+    "metadata": {
+        "id": "jobTitle",
+        "name": "Job Title",
+        "tags": [
+            "properties",
+            "profileProperties",
+            "workProfileProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "profileProperties",
-        "workProfileProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "602.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/latitude.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/latitude.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/latitude.json
index 1f8c92c..0f72c88 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/latitude.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/latitude.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "latitude", "name": "Latitude"   },
+    "metadata": {
+        "id": "latitude",
+        "name": "Latitude",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "geographicSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "geographicSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "4.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/longitude.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/longitude.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/longitude.json
index f983d52..7cbcd7a 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/longitude.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/longitude.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "longitude", "name": "Longitude"   },
+    "metadata": {
+        "id": "longitude",
+        "name": "Longitude",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "geographicSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "geographicSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "5.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv1.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv1.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv1.json
index 7591485..c8939ce 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv1.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv1.json
@@ -1,11 +1,14 @@
 {
-  "metadata": {     "id": "sessionAdminSubDiv1", "name": "State/Region/Province"   },
+  "metadata": {
+    "id": "sessionAdminSubDiv1",
+    "name": "State/Region/Province",
+    "tags": [
+      "properties",
+      "sessionProperties",
+      "geographicSessionProperties"
+    ]
+  },
   "type": "string",
-  "tags": [
-    "properties",
-    "sessionProperties",
-    "geographicSessionProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [ ],
   "rank": "2.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv2.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv2.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv2.json
index 2f7a7e2..bad2a10 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv2.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionAdminSubDiv2.json
@@ -1,11 +1,14 @@
 {
-  "metadata": {     "id": "sessionAdminSubDiv2", "name": "SubRegion/County"   },
+  "metadata": {
+    "id": "sessionAdminSubDiv2",
+    "name": "SubRegion/County",
+    "tags": [
+      "properties",
+      "sessionProperties",
+      "geographicSessionProperties"
+    ]
+  },
   "type": "string",
-  "tags": [
-    "properties",
-    "sessionProperties",
-    "geographicSessionProperties"
-  ],
   "defaultValue": "",
   "automaticMappingsFrom": [ ],
   "rank": "2.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCity.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCity.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCity.json
index 2f353e5..57632ca 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCity.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCity.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "sessionCity", "name": "City"   },
+    "metadata": {
+        "id": "sessionCity",
+        "name": "City",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "geographicSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "geographicSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "3.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryCode.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryCode.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryCode.json
index 47cbe2c..38e7680 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryCode.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryCode.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "sessionCountryCode", "name": "Country code"   },
+    "metadata": {
+        "id": "sessionCountryCode",
+        "name": "Country code",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "geographicSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "geographicSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ "j:country" ],
     "rank": "1.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryName.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryName.json b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryName.json
index 4198d30..ff61cc0 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryName.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/geographic/sessionCountryName.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "sessionCountryName", "name": "Country"   },
+    "metadata": {
+        "id": "sessionCountryName",
+        "name": "Country",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "geographicSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "geographicSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "2.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/deviceCategory.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/deviceCategory.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/deviceCategory.json
index 3795e96..706915f 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/deviceCategory.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/deviceCategory.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "deviceCategory", "name": "Device category"   },
+    "metadata": {
+        "id": "deviceCategory",
+        "name": "Device category",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "105.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemFamily.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemFamily.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemFamily.json
index b1f9653..bce7688 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemFamily.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemFamily.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "operatingSystemFamily", "name": "Operating system family"   },
+    "metadata": {
+        "id": "operatingSystemFamily",
+        "name": "Operating system family",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "101.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemName.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemName.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemName.json
index bf08a07..5d77863 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemName.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/operatingSystemName.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "operatingSystemName", "name": "Operating system name"   },
+    "metadata": {
+        "id": "operatingSystemName",
+        "name": "Operating system name",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "102.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/pageReferringURL.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/pageReferringURL.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/pageReferringURL.json
index c971bc9..378a97c 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/pageReferringURL.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/pageReferringURL.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "pageReferringURL", "name": "Previous page URL"   },
+    "metadata": {
+        "id": "pageReferringURL",
+        "name": "Previous page URL",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "108.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteAddr.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteAddr.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteAddr.json
index 71531de..8231c2f 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteAddr.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteAddr.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "remoteAddr", "name": "Remote IP address"   },
+    "metadata": {
+        "id": "remoteAddr",
+        "name": "Remote IP address",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "106.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteHost.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteHost.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteHost.json
index 1864348..b33265e 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteHost.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/remoteHost.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "remoteHost", "name": "Remote host address"   },
+    "metadata": {
+        "id": "remoteHost",
+        "name": "Remote host address",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "107.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentName.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentName.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentName.json
index 8849081..1a2855d 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentName.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentName.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "userAgentName", "name": "Browser user agent name"   },
+    "metadata": {
+        "id": "userAgentName",
+        "name": "Browser user agent name",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "103.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentVersion.json
----------------------------------------------------------------------
diff --git a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentVersion.json b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentVersion.json
index 343f3bf..0675427 100644
--- a/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentVersion.json
+++ b/services/src/main/resources/META-INF/cxs/properties/sessions/technical/userAgentVersion.json
@@ -1,11 +1,14 @@
 {
-    "metadata": {     "id": "userAgentVersion", "name": "Browser user agent version"   },
+    "metadata": {
+        "id": "userAgentVersion",
+        "name": "Browser user agent version",
+        "tags": [
+            "properties",
+            "sessionProperties",
+            "technicalSessionProperties"
+        ]
+    },
     "type": "string",
-    "tags": [
-        "properties",
-        "sessionProperties",
-        "technicalSessionProperties"
-    ],
     "defaultValue": "",
     "automaticMappingsFrom": [ ],
     "rank": "104.0"

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/src/site/markdown/versions/1.1/concepts.md
----------------------------------------------------------------------
diff --git a/src/site/markdown/versions/1.1/concepts.md b/src/site/markdown/versions/1.1/concepts.md
index 56a7e7c..4f4e7be 100644
--- a/src/site/markdown/versions/1.1/concepts.md
+++ b/src/site/markdown/versions/1.1/concepts.md
@@ -50,9 +50,9 @@ Some types can be dynamically defined at runtime by calling to the REST API whil
     "itemType": "propertyType",
     "metadata": {
         "id": "tweetNb",
-        "name": "tweetNb"
+        "name": "tweetNb",
+        "tags": ["social"]
     },
-    "tags": ["social"],
     "target": "profiles",
     "type": "integer"
 }

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/src/site/markdown/versions/master/concepts.md
----------------------------------------------------------------------
diff --git a/src/site/markdown/versions/master/concepts.md b/src/site/markdown/versions/master/concepts.md
index 57ef1e2..8b33c89 100644
--- a/src/site/markdown/versions/master/concepts.md
+++ b/src/site/markdown/versions/master/concepts.md
@@ -50,9 +50,9 @@ Some types can be dynamically defined at runtime by calling to the REST API whil
     "itemType": "propertyType",
     "metadata": {
         "id": "tweetNb",
-        "name": "tweetNb"
+        "name": "tweetNb",
+        "tags": ["social"]
     },
-    "tags": ["social"],
     "target": "profiles",
     "type": "integer"
 }

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/src/site/markdown/versions/master/custom-extensions.md
----------------------------------------------------------------------
diff --git a/src/site/markdown/versions/master/custom-extensions.md b/src/site/markdown/versions/master/custom-extensions.md
index 355896a..866f4f9 100644
--- a/src/site/markdown/versions/master/custom-extensions.md
+++ b/src/site/markdown/versions/master/custom-extensions.md
@@ -158,9 +158,12 @@ For profile properties you must create the JSON file inside the directory in you
 Here is an example of a property definition JSON file
 
     {
-        "metadata": {     "id": "city", "name": "City"   },
+        "metadata": {
+            "id": "city",
+            "name": "City",
+            "tags": ["properties", "profileProperties", "contactProfileProperties"]
+        },
         "type": "string",
-        "tags": ["contactProfileProperties"],
         "defaultValue": "",
         "automaticMappingsFrom": [ ],
         "rank": "304.0"
diff --git a/rest/src/main/java/org/apache/unomi/rest/ProfileServiceEndPoint.java b/rest/src/main/java/org/apache/unomi/rest/ProfileServiceEndPoint.java
index e7c35ce..156eb91 100644
--- a/rest/src/main/java/org/apache/unomi/rest/ProfileServiceEndPoint.java
+++ b/rest/src/main/java/org/apache/unomi/rest/ProfileServiceEndPoint.java
@@ -475,15 +475,14 @@ public class ProfileServiceEndPoint {
      * TODO: move to a different class
      * Deprecated : use a /properties/targets collection instead, this URI will be used for looking up properties by id instead.
      *
      * @param target   the target for which we want to retrieve the associated property types
      * @param language the value of the {@code Accept-Language} header to specify in which locale the properties description should be returned TODO unused
      * @return a collection of all the property types associated with the specified target
      */
     @GET
-    @Path("/properties/{target}")
-    @Deprecated
-    public Collection<PropertyType> getPropertyTypesByTargetDeprecated(@PathParam("target") String target, @HeaderParam("Accept-Language") String language) {
-        return profileService.getAllPropertyTypes(target);
+    @Path("/properties/{propertyId}")
+    public PropertyType getPropertyType(@PathParam("propertyId") String propertyId, @HeaderParam("Accept-Language") String language) {
+        return profileService.getPropertyType(propertyId);
     }
 
     /**
@@ -497,7 +496,6 @@ public class ProfileServiceEndPoint {
      */
     @GET
     @Path("/properties/targets/{target}")
-    @Deprecated
     public Collection<PropertyType> getPropertyTypesByTarget(@PathParam("target") String target, @HeaderParam("Accept-Language") String language) {
         return profileService.getAllPropertyTypes(target);
     }

http://git-wip-us.apache.org/repos/asf/incubator-unomi/blob/a5beefc4/samples/tweet-button-plugin/src/main/java/org/apache/unomi/samples/tweet_button_plugin/actions/IncrementTweetNumberAction.java
----------------------------------------------------------------------
@@ -475,15 +475,14 @@ public class ProfileServiceEndPoint {
      * Deprecated : use a /properties/targets collection instead, this URI will be used for looking up properties by id instead.
      *
-     * @param target   the target for which we want to retrieve the associated property types
-     * @param language the value of the {@code Accept-Language} header to specify in which locale the properties description should be returned TODO unused
+     * @param propertyId    the target for which we want to retrieve the associated property types
+     * @param language      the value of the {@code Accept-Language} header to specify in which locale the properties description should be returned TODO unused
      * @return a collection of all the property types associated with the specified target
      */